intelmq.bots.outputs.stomp package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.stomp package

## Submodules

## intelmq.bots.outputs.stomp.output module

`intelmq.bots.outputs.stomp.output.` `BOT`

  alias of `intelmq.bots.outputs.stomp.output.StompOutputBot`

class `intelmq.bots.outputs.stomp.output.` `StompOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Send events to a STMOP server

  `connect`()
  `exchange`: str = '/exchange/_push'
  `heartbeat`: int = 60000
  `http_verify_cert`: Union[bool, str] = True
  `init`()
  `keep_raw_field`: bool = False
  `message_hierarchical_output`: bool = False
  `message_jsondict_as_string`: bool = False
  `message_with_type`: bool = False
  `port`: int = 61614
  `process`()
  `server`: str = '127.0.0.1'
  `shutdown`()
  `single_key`: bool = False
  `ssl_ca_certificate`: str = 'ca.pem'
  `ssl_client_certificate`: str = 'client.pem'
  `ssl_client_certificate_key`: str = 'client.key'

## Module contents